autowisp.database.data_model.provenance package — AutoWISP documentation

# autowisp.database.data_model.provenance package

## Class Inheritance Diagram

Add all tables to __all__.

class autowisp.database.data_model.provenance.Camera(**kwargs)

  Bases: `DataModelBase`

  The table describing the camera specified

  __str__()

    Human readable info for the camera.

  camera_type
  camera_type_id

    The id of the camera type

  channels
  id

    A unique identifier for each row.

  notes

    The notes provided for the camera

  observers
  observing_sessions
  serial_number

    The serial number of the camera

  timestamp

    When record was last changed

class autowisp.database.data_model.provenance.CameraAccess(**kwargs)

  Bases: `DataModelBase`

  The table describing the camera access

  camera_id

    A unique identifier of the camera

  id

    A unique identifier for each row.

  observer_id

    A unique identifier for the observer

  timestamp

    When record was last changed

class autowisp.database.data_model.provenance.CameraChannel(**kwargs)

  Bases: `DataModelBase`

  The table describing each of the channels of a type of camera.

  camera_type_id

    The camera type to which this channel belongs.

  id

    A unique identifier for each row.

  name

    A label to assign to the channel.

  timestamp

    When record was last changed

  x_offset

    The x index of the first pixel of the channel.

  x_step

    The step in the x direction between consecutive pixels of the channel.

  y_offset

    The y index of the first pixel of the channel.

  y_step

    The step in the y direction between consecutive pixels of the channel.

class autowisp.database.data_model.provenance.CameraType(**kwargs)

  Bases: `DataModelBase`

  The table describing the different camera types

  cameras
  channels
  id

    A unique identifier for each row.

  make

    The make of the camera

  model

    The model of the camera

  notes

    The notes provided for the camera type

  pixel_size

    The pixel size of the camera in microns

  sensor_type

    The sensor type of the camera

  timestamp

    When record was last changed

  version

    The version of the camera

  x_resolution

    The x_resolution of the camera

  y_resolution

    The y_resolution of the camera

class autowisp.database.data_model.provenance.Mount(**kwargs)

  Bases: `DataModelBase`

  The table describing the mounts specified

  __str__()

    Human readable info for the mount.

  id

    A unique identifier for each row.

  mount_type
  mount_type_id

    The identifier of the mount type

  notes

    The notes provided for the mount

  observers
  observing_sessions
  serial_number

    The serial number for each mount

  timestamp

    When record was last changed

class autowisp.database.data_model.provenance.MountAccess(**kwargs)

  Bases: `DataModelBase`

  The table dscribing the mount access

  id

    A unique identifier for each row.

  mount_id

    A unique identifier of the mount

  observer_id

    A unique identifier for the observer

  timestamp

    When record was last changed

class autowisp.database.data_model.provenance.MountType(**kwargs)

  Bases: `DataModelBase`

  The table describing the different mount types

  id

    A unique identifier for each row.

  make

    The make of the mount type

  model

    The model for each mount type

  mounts
  notes

    The notes provided for the mount type

  timestamp

    When record was last changed

  version

    The version of the mount type

class autowisp.database.data_model.provenance.Observatory(**kwargs)

  Bases: `DataModelBase`

  The table describing the observatory

  __str__()

    Human readable identifier for the observatory.

  altitude

    The altitude of the observatory

  id

    A unique identifier for each row.

  latitude

    The latitude of the observatory

  longitude

    The longitude of the observatory

  name

    The name of the observatory

  observing_sessions
  timestamp

    When record was last changed

class autowisp.database.data_model.provenance.Observer(**kwargs)

  Bases: `DataModelBase`

  The table describing the observers

  __str__()

    Human readable string identifying the observer.

  cameras
  email

    The email of the observer

  id

    A unique identifier for each row.

  mounts
  name

    The name of the observer

  notes

    Any user supplied notes describing the observer.

  observing_sessions
  phone

    The phone number of the observer

  telescopes
  timestamp

    When record was last changed

class autowisp.database.data_model.provenance.Telescope(**kwargs)

  Bases: `DataModelBase`

  The table describing the telescopes specified

  __str__()

    Human readable identifier for the telescope.

  id

    A unique identifier for each row.

  notes

    The notes provided for the telescope

  observers
  observing_sessions
  serial_number

    The serial number of the telescope

  telescope_type
  telescope_type_id

    The id of the telescope type

  timestamp

    When record was last changed

class autowisp.database.data_model.provenance.TelescopeAccess(**kwargs)

  Bases: `DataModelBase`

  The table describing the telescope access

  id

    A unique identifier for each row.

  observer_id

    A unique identifier for the observer

  telescope_id

    A unique identifier of the telescope

  timestamp

    When record was last changed

class autowisp.database.data_model.provenance.TelescopeType(**kwargs)

  Bases: `DataModelBase`

  The table dscribing the different telescope types

  f_ratio

    The focal ratio of the telescope

  focal_length

    The focal length of the telescope in mm

  id

    A unique identifier for each row.

  make

    The make of the telescope

  model

    The model of the telescope

  notes

    The notes provided for the telescope type

  telescopes
  timestamp

    When record was last changed

  version

    The version of the telescope

## Submodules

- autowisp.database.data_model.provenance.camera module
  - Class Inheritance Diagram
  - `Camera`
    - `Camera.__str__()`
    - `Camera.camera_type`
    - `Camera.camera_type_id`
    - `Camera.channels`
    - `Camera.id`
    - `Camera.notes`
    - `Camera.observers`
    - `Camera.observing_sessions`
    - `Camera.serial_number`
    - `Camera.timestamp`
- autowisp.database.data_model.provenance.camera_access module
  - Class Inheritance Diagram
  - `CameraAccess`
    - `CameraAccess.camera_id`
    - `CameraAccess.id`
    - `CameraAccess.observer_id`
    - `CameraAccess.timestamp`
- autowisp.database.data_model.provenance.camera_channel module
  - Class Inheritance Diagram
  - `CameraChannel`
    - `CameraChannel.camera_type_id`
    - `CameraChannel.id`
    - `CameraChannel.name`
    - `CameraChannel.timestamp`
    - `CameraChannel.x_offset`
    - `CameraChannel.x_step`
    - `CameraChannel.y_offset`
    - `CameraChannel.y_step`
- autowisp.database.data_model.provenance.camera_type module
  - Class Inheritance Diagram
  - `CameraType`
    - `CameraType.cameras`
    - `CameraType.channels`
    - `CameraType.id`
    - `CameraType.make`
    - `CameraType.model`
    - `CameraType.notes`
    - `CameraType.pixel_size`
    - `CameraType.sensor_type`
    - `CameraType.timestamp`
    - `CameraType.version`
    - `CameraType.x_resolution`
    - `CameraType.y_resolution`
- autowisp.database.data_model.provenance.mount module
  - Class Inheritance Diagram
  - `Mount`
    - `Mount.__str__()`
    - `Mount.id`
    - `Mount.mount_type`
    - `Mount.mount_type_id`
    - `Mount.notes`
    - `Mount.observers`
    - `Mount.observing_sessions`
    - `Mount.serial_number`
    - `Mount.timestamp`
- autowisp.database.data_model.provenance.mount_access module
  - Class Inheritance Diagram
  - `MountAccess`
    - `MountAccess.id`
    - `MountAccess.mount_id`
    - `MountAccess.observer_id`
    - `MountAccess.timestamp`
- autowisp.database.data_model.provenance.mount_type module
  - Class Inheritance Diagram
  - `MountType`
    - `MountType.id`
    - `MountType.make`
    - `MountType.model`
    - `MountType.mounts`
    - `MountType.notes`
    - `MountType.timestamp`
    - `MountType.version`
- autowisp.database.data_model.provenance.observatory module
  - Class Inheritance Diagram
  - `Observatory`
    - `Observatory.__str__()`
    - `Observatory.altitude`
    - `Observatory.id`
    - `Observatory.latitude`
    - `Observatory.longitude`
    - `Observatory.name`
    - `Observatory.observing_sessions`
    - `Observatory.timestamp`
- autowisp.database.data_model.provenance.observer module
  - Class Inheritance Diagram
  - `Observer`
    - `Observer.__str__()`
    - `Observer.cameras`
    - `Observer.email`
    - `Observer.id`
    - `Observer.mounts`
    - `Observer.name`
    - `Observer.notes`
    - `Observer.observing_sessions`
    - `Observer.phone`
    - `Observer.telescopes`
    - `Observer.timestamp`
- autowisp.database.data_model.provenance.telescope module
  - Class Inheritance Diagram
  - `Telescope`
    - `Telescope.__str__()`
    - `Telescope.id`
    - `Telescope.notes`
    - `Telescope.observers`
    - `Telescope.observing_sessions`
    - `Telescope.serial_number`
    - `Telescope.telescope_type`
    - `Telescope.telescope_type_id`
    - `Telescope.timestamp`
- autowisp.database.data_model.provenance.telescope_access module
  - Class Inheritance Diagram
  - `TelescopeAccess`
    - `TelescopeAccess.id`
    - `TelescopeAccess.observer_id`
    - `TelescopeAccess.telescope_id`
    - `TelescopeAccess.timestamp`
- autowisp.database.data_model.provenance.telescope_type module
  - Class Inheritance Diagram
  - `TelescopeType`
    - `TelescopeType.f_ratio`
    - `TelescopeType.focal_length`
    - `TelescopeType.id`
    - `TelescopeType.make`
    - `TelescopeType.model`
    - `TelescopeType.notes`
    - `TelescopeType.telescopes`
    - `TelescopeType.timestamp`
    - `TelescopeType.version`